From 1b929d174916a0e226c72927932bdbdd1230dcb0 Mon Sep 17 00:00:00 2001
From: Bruce Momjian <bruce@momjian.us>
Date: Wed, 11 Dec 1996 22:58:16 +0000
Subject: [PATCH] Postgres95 to PostgreSQL.

---
 src/bin/psql/psql.c | 8 ++++----
 src/man/pg_dump.1   | 4 ++--
 src/man/postgres.1  | 4 ++--
 src/man/psql.1      | 6 +++---
 4 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/src/man/pg_dump.1 b/src/man/pg_dump.1
index a623548622c..b211629ed64 100644
--- a/src/man/pg_dump.1
+++ b/src/man/pg_dump.1
@@ -1,6 +1,6 @@
 .\" This is -*-nroff-*-
 .\" XXX standard disclaimer belongs here....
-.\" $Header: /cvsroot/pgsql/src/man/Attic/pg_dump.1,v 1.3 1996/12/11 00:27:59 momjian Exp $
+.\" $Header: /cvsroot/pgsql/src/man/Attic/pg_dump.1,v 1.4 1996/12/11 22:58:11 momjian Exp $
 .TH PG_DUMP UNIX 1/20/96 PostgreSQL PostgreSQL
 .SH NAME
 pg_dump \(em dumps out a Postgres database into a script file
@@ -55,7 +55,7 @@ for textual editing.
 .PP
 .IR "pg_dump" 
 is useful for dumping out the contents of a database to move from one
-postgres95 installation to another.  After running 
+postgreSQL installation to another.  After running 
 .IR "pg_dump"
 , one should examine the output script file for any warnings, especially
 in light of the limitations listed below. 
diff --git a/src/man/postgres.1 b/src/man/postgres.1
index e39c614b173..09767c52c7e 100644
--- a/src/man/postgres.1
+++ b/src/man/postgres.1
@@ -1,7 +1,7 @@
 .\" This is -*-nroff-*-
 .\" XXX standard disclaimer belongs here....
-.\" $Header: /cvsroot/pgsql/src/man/Attic/postgres.1,v 1.3 1996/12/11 00:28:00 momjian Exp $
-.TH POSTGRES95 UNIX 11/05/95 Postgres95 Postgres95
+.\" $Header: /cvsroot/pgsql/src/man/Attic/postgres.1,v 1.4 1996/12/11 22:58:14 momjian Exp $
+.TH POSTGRES95 UNIX 12/08/96 Postgres95 Postgres95
 .SH NAME
 postgres \(em the Postgres backend server
 .SH SYNOPSIS
diff --git a/src/man/psql.1 b/src/man/psql.1
index b48d852d75a..3a5cdc98d1e 100644
--- a/src/man/psql.1
+++ b/src/man/psql.1
@@ -1,6 +1,6 @@
 .\" This is -*-nroff-*-
 .\" XXX standard disclaimer belongs here....
-.\" $Header: /cvsroot/pgsql/src/man/Attic/psql.1,v 1.4 1996/12/11 00:28:03 momjian Exp $
+.\" $Header: /cvsroot/pgsql/src/man/Attic/psql.1,v 1.5 1996/12/11 22:58:16 momjian Exp $
 .TH PSQL UNIX 1/20/96 PostgreSQL PostgreSQL
 .SH NAME
 psql \(em run the interactive query front-end
@@ -209,8 +209,8 @@ In normal operation, psql provides a prompt with the name of the
 database that psql is current connected to followed by the string "=>".
 For example,
 .nf
-Welcome to the POSTGRES95 interactive sql monitor:
-  Please read the file COPYRIGHT for copyright terms of POSTGRES95
+Welcome to the POSTGRESQL interactive sql monitor:
+  Please read the file COPYRIGHT for copyright terms of POSTGRESQL
 
    type \e? for help on slash commands
    type \eq to quit
diff --git a/src/bin/psql/psql.c b/src/bin/psql/psql.c
index 7c60d22b604..34a26a257c3 100644
--- a/src/bin/psql/psql.c
+++ b/src/bin/psql/psql.c
@@ -1,13 +1,13 @@
 /*-------------------------------------------------------------------------
  *
  * psql.c--
  *    an interactive front-end to postgres95
  *
  * Copyright (c) 1996, Regents of the University of California
  *
  *
  * IDENTIFICATION
- *    $Header: /cvsroot/pgsql/src/bin/psql/Attic/psql.c,v 1.37 1996/12/01 20:28:39 momjian Exp $
+ *    $Header: /cvsroot/pgsql/src/bin/psql/Attic/psql.c,v 1.38 1996/12/11 22:57:34 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -1536,9 +1536,9 @@ main(int argc, char **argv)
 	exit(listAllDbs(&settings));
     }
     if (!settings.quiet && !singleQuery && !qfilename) {
-	printf("Welcome to the POSTGRES95 interactive sql monitor:\n");
+	printf("Welcome to the POSTGRESQL interactive sql monitor:\n");
 	printf("  Please read the file COPYRIGHT for copyright terms "
-	       "of POSTGRES95\n\n");
+	       "of POSTGRESQL\n\n");
 	printf("   type \\? for help on slash commands\n");
 	printf("   type \\q to quit\n");
 	printf("   type \\g or terminate with semicolon to execute query\n");
@@ -1,13 +1,13 @@
  *
  * psql.c--
- *    an interactive front-end to postgres95
+ *    an interactive front-end to postgreSQL
  *
  * Copyright (c) 1996, Regents of the University of California
-- 
GitLab